import React, { useState, useEffect } from 'react';
import { Form, Icon, Input, Button, DatePicker, Select, Card, Row, Col, Pagination, Alert, Radio, Tag, Tooltip, Tabs, Table, notification } from 'antd';
import moment from 'moment';
import request from '../../../../../utils/request';
import apis from '../../../../../services/apis';
import Styles from '../style.less';
import { router } from 'umi';


const saleType = [
  {
    id: 1,
    name: '待定',
  },
  {
    id: 2,
    name: '售罄',
  },
  {
    id: 3,
    name: '在售',
  },
]

/**
 *图片设置
 *
 * @param {*} props
 * @returns
 */
function imageSet(props) {
  // eslint-disable-next-line react-hooks/rules-of-hooks
  const [data, setData] = useState([])

  // eslint-disable-next-line react-hooks/rules-of-hooks
  useEffect(() => {
    getList()
  }, [])

  function openNotificationWithIcon(type, message) {
    notification[type]({
      message,
      description:
        '',
    });
  }

  function getList(params) {
    console.log(props)
    // 网路请求
    const { url, method } = apis.building.buildingApartment
    const tempUrl = url.substring(0, url.lastIndexOf('id')).concat(props.building.buildingId)

    request({ url: tempUrl, method, params: { ...params } }).then(res => {
      setData(res)
    }).catch(err => {
      openNotificationWithIcon('error', err)
    })
  }


  const columns = [
    {
      title: '名称',
      dataIndex: 'apartmentName',
      key: 'apartmentName',
    },
    {
      title: '类型',
      dataIndex: 'apartmentType',
      key: 'apartmentType',
      render: (_, record) => <span>{ record.apartmentType === 'apart' ? '户型' : '相册' }</span>,
    },
    {
      title: '销售状态',
      dataIndex: 'marketStatus',
      key: 'marketStatus',
      render: (_, record) => <span>{ (saleType.filter(x => x.id == record.marketStatus)[0] || {}).name }</span>,
    },
    {
      title: '备注',
      dataIndex: 'remark',
      key: 'remark',
    },
    {
      title: '创建时间',
      dataIndex: 'createDate',
      key: 'createDate',
      render: (_, record) => <span>{ moment(record.createDate).format('YYYY-MM-DD') }</span>,
    },
    {
      title: '操作',
      dataIndex: 'apartmentId',
      key: 'apartmentId',
      render: (_, record) => (
        <>
          <Button type="link" style={{ color: 'red' }}>编辑</Button>
          <Button type="link" style={{ color: 'red' }}>删除</Button>
        </>
      ),
    },
  ]

  return (
    <>
      <Button type="primary">新增图片库</Button>
      <Table dataSource={data} columns={columns} pagination={false} />
    </>
  )
}

export default imageSet
